summaryrefslogtreecommitdiff
path: root/ace/Svc_Conf.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-09-12 03:37:51 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-09-12 03:37:51 +0000
commitfb59ede8031fb55739160a0753d2a4cd2d6546af (patch)
treeb7abff4feff6894c93ec2ec491fcc93a0df9199c /ace/Svc_Conf.h
parentbf52076b82447057f33cd5ca6fc7ab8fd955c9c1 (diff)
downloadATCD-fb59ede8031fb55739160a0753d2a4cd2d6546af.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Svc_Conf.h')
-rw-r--r--ace/Svc_Conf.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ace/Svc_Conf.h b/ace/Svc_Conf.h
index 50e12df8d44..e1c71659225 100644
--- a/ace/Svc_Conf.h
+++ b/ace/Svc_Conf.h
@@ -64,8 +64,8 @@ extern int ace_yyleng;
extern ACE_Obstack *ace_obstack;
// Efficient memory allocation technique
-ACE_Service_Type *ace_create_service_type (const char *, int, const void *, unsigned int);
-// Factory that creates a new ACE_Service_Type.
+ACE_Service_Type_Impl *ace_create_service_type (const char *, int, const void *, unsigned int);
+// Factory that creates a new ACE_Service_Type_Impl.
typedef union
{
@@ -73,7 +73,7 @@ typedef union
ACE_Location_Node *location_node_;
ACE_Parse_Node *parse_node_;
ACE_Static_Node *static_node_;
- ACE_Service_Record *svc_record_;
+ ACE_Service_Type *svc_record_;
char *ident_;
} YYSTYPE;
extern YYSTYPE ace_yylval;